"""
URL configuration for django_firebase_mcp project.

The `urlpatterns` list routes URLs to views. For more information please see:
    https://docs.djangoproject.com/en/5.2/topics/http/urls/
Examples:
Function views
    1. Add an import:  from my_app import views
    2. Add a URL to urlpatterns:  path('', views.home, name='home')
Class-based views
    1. Add an import:  from other_app.views import Home
    2. Add a URL to urlpatterns:  path('', Home.as_view(), name='home')
Including another URLconf
    1. Import the include() function: from django.urls import include, path
    2. Add a URL to urlpatterns:  path('blog/', include('blog.urls'))
"""
from django.contrib import admin
from django.urls import path, include
from drf_spectacular.views import SpectacularAPIView, SpectacularSwaggerView, SpectacularRedocView
from rest_framework_simplejwt.views import TokenObtainPairView, TokenRefreshView, TokenVerifyView

urlpatterns = [
    path('admin/', admin.site.urls),

    # API Schema and Documentation
    path('api/schema/', SpectacularAPIView.as_view(), name='schema'),
    path('api/schema/swagger-ui/',
         SpectacularSwaggerView.as_view(url_name='schema'), name='swagger-ui'),
    path('api/redoc/', SpectacularRedocView.as_view(url_name='schema'), name='redoc'),

    # Authentication URLs
    # Login, logout, password reset, etc.
    path('api/auth/', include('dj_rest_auth.urls')),
    path('api/auth/registration/',
         include('dj_rest_auth.registration.urls')),  # Registration
    # Django-allauth URLs for email confirmation
    path('accounts/', include('allauth.urls')),

    # JWT Token URLs (direct access)
    path('api/token/', TokenObtainPairView.as_view(), name='token_obtain_pair'),
    path('api/token/refresh/', TokenRefreshView.as_view(), name='token_refresh'),
    path('api/token/verify/', TokenVerifyView.as_view(),
         name='token_verify'),    # Include base app URLs if they exist
    path('api/', include('base.urls')),

    # Firebase MCP URLs
    path('mcp/', include('firebase_admin_mcp.urls')),
]



from django.contrib import admin
from . import models

for model_name, model in models.__dict__.items():
    try:
        admin.site.register(model) if str(
            type(model)) == "<class 'django.db.models.base.ModelBase'>" else None
    except admin.sites.AlreadyRegistered:
        continue
    except Exception as e:
        # print(e)
        continue


import json as json
from rest_framework.pagination import PageNumberPagination
from rest_framework.viewsets import ModelViewSet
from rest_framework.status import *
from rest_framework.filters import SearchFilter, OrderingFilter
# from url_filter.integrations.drf import DjangoFilterBackend
from django_filters.rest_framework import DjangoFilterBackend

from .models import *


class BaseModelViewSet(ModelViewSet):
    """BaseModelViewSet

    By default has all fields enabled for filtering, searching and ordering
    Pagination enabled

    """

    filter_backends = [DjangoFilterBackend, SearchFilter, OrderingFilter]
    pagination_class = PageNumberPagination

    class Meta:
        abstract = True

    def __init__(self, **kwargs):
        self.setup_viewset()
        super().__init__(**kwargs)

    def setup_viewset(self):
        all_model_fields = self.queryset.model.get_all_fields()
        self.filter_fields = all_model_fields
        self.search_fields = self.queryset.model.get_all_search_fields()
        self.ordering_fields = all_model_fields
        self.pagination_class.page_size = 100
        self.queryset = self.queryset.order_by("-created_on")



from django.contrib.auth import get_user_model
from django.utils.html import strip_tags
from django.core.mail import EmailMultiAlternatives, EmailMessage
from django.template.loader import get_template
from django.conf import settings

User = get_user_model()

def temporary_password_send(user, password):
    """ Sends an email with temporary login credentials to the user.
    Args:
        user (User): The user object containing the temporary password.
    """
    subject = strip_tags('Temporary Login Credentials Inside')
    body = get_template('temp_password.html').render({'user':user,'password': password})
    msg = EmailMessage(subject, body, settings.FROM_EMAIL, [user.email])
    msg.content_subtype = "html"
    msg.send()

User.objects.filter(email='t7965@mailinator.com').delete()


"""
Django settings for django_firebase_mcp project.

Generated by 'django-admin startproject' using Django 5.2.1.

For more information on this file, see
https://docs.djangoproject.com/en/5.2/topics/settings/

For the full list of settings and their values, see
https://docs.djangoproject.com/en/5.2/ref/settings/
"""

import os
from datetime import timedelta
from pathlib import Path
from dotenv import load_dotenv

# Build paths inside the project like this: BASE_DIR / 'subdir'.
BASE_DIR = Path(__file__).resolve().parent.parent

# Load environment variables from .env file
load_dotenv(BASE_DIR / '.env')


# Quick-start development settings - unsuitable for production
# See https://docs.djangoproject.com/en/5.2/howto/deployment/checklist/

# SECURITY WARNING: keep the secret key used in production secret!
SECRET_KEY = 'django-insecure-(3c_58*ou+j^+ve0&x0kk%*$5!x*3+@@jnc(lwx$@r*kr%gy8o'

# SECURITY WARNING: don't run with debug turned on in production!
DEBUG = True

ALLOWED_HOSTS = []

CSRF_COOKIE_SECURE = True
SESSION_COOKIE_SECURE = True
AUTH_USER_MODEL = 'base_user.User'

# Application definition

INSTALLED_APPS = [
    'django.contrib.admin',
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.messages',
    'django.contrib.staticfiles',
    'django.contrib.sites',  # Required for allauth

    # Third party apps
    'rest_framework',  # Added DRF
    'rest_framework.authtoken',  # Token authentication
    'rest_framework_simplejwt',  # JWT authentication
    'drf_spectacular',  # Added drf-spectacular
    'corsheaders',  # CORS support

    # Authentication apps
    'allauth',
    'allauth.account',
    'allauth.socialaccount',
    'dj_rest_auth',
    'dj_rest_auth.registration',

    # Local apps
    'base',
    'base_user',
]

MIDDLEWARE = [
    'django.middleware.security.SecurityMiddleware',
    'django.contrib.sessions.middleware.SessionMiddleware',
    'corsheaders.middleware.CorsMiddleware',  # Add CORS middleware
    'django.middleware.common.CommonMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'allauth.account.middleware.AccountMiddleware',  # Required for allauth
    'django.contrib.messages.middleware.MessageMiddleware',
    'django.middleware.clickjacking.XFrameOptionsMiddleware',
]

ROOT_URLCONF = 'django_firebase_mcp.urls'

TEMPLATES = [
    {
        'BACKEND': 'django.template.backends.django.DjangoTemplates',        'DIRS': [],
        'APP_DIRS': True,
        'OPTIONS': {
            'context_processors': [
                'django.template.context_processors.request',
                'django.contrib.auth.context_processors.auth',
                'django.contrib.messages.context_processors.messages',
            ],
        },
    },
]

WSGI_APPLICATION = 'django_firebase_mcp.wsgi.application'


# Database
# https://docs.djangoproject.com/en/5.2/ref/settings/#databases

DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.sqlite3',
        'NAME': BASE_DIR / 'db.sqlite3',
    }
}


# Password validation
# https://docs.djangoproject.com/en/5.2/ref/settings/#auth-password-validators

AUTH_PASSWORD_VALIDATORS = [
    {
        'NAME': 'django.contrib.auth.password_validation.UserAttributeSimilarityValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation.MinimumLengthValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation.CommonPasswordValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation.NumericPasswordValidator',
    },
]


# Internationalization
# https://docs.djangoproject.com/en/5.2/topics/i18n/

LANGUAGE_CODE = 'en-us'

TIME_ZONE = 'UTC'

USE_I18N = True

USE_TZ = True


# Static files (CSS, JavaScript, Images)
# https://docs.djangoproject.com/en/5.2/howto/static-files/

STATIC_URL = 'static/'

# Default primary key field type
# https://docs.djangoproject.com/en/5.2/ref/settings/#default-auto-field

DEFAULT_AUTO_FIELD = 'django.db.models.BigAutoField'

REST_FRAMEWORK = {
    'DEFAULT_SCHEMA_CLASS': 'drf_spectacular.openapi.AutoSchema',
    'DEFAULT_AUTHENTICATION_CLASSES': [
        'rest_framework_simplejwt.authentication.JWTAuthentication',
    ],
    'DEFAULT_PERMISSION_CLASSES': [
        'rest_framework.permissions.IsAuthenticated',
    ],
}

SPECTACULAR_SETTINGS = {
    'TITLE': 'django_firebase_mcp API',
    'DESCRIPTION': 'API documentation for the django_firebase_mcp project.',
    'VERSION': '1.0.0',
    'COMPONENT_SPLIT_REQUEST': True,
    'SCHEMA_PATH_PREFIX': '/api/',
}

# Django Sites Framework
SITE_ID = 1


# -------------------------------------------------- ALLAUTH CONFIGURATIONS --------------------------------------------------

AUTHENTICATION_BACKENDS = (
    'django.contrib.auth.backends.ModelBackend',
    'allauth.account.auth_backends.AuthenticationBackend',
)
ACCOUNT_USER_MODEL_USERNAME_FIELD = None
ACCOUNT_EMAIL_VERIFICATION = "mandatory"
ACCOUNT_LOGIN_METHODS = {"email"}
ACCOUNT_LOGOUT_ON_PASSWORD_CHANGE = True
ACCOUNT_LOGIN_BY_CODE_ENABLED = True
ACCOUNT_EMAIL_VERIFICATION_BY_CODE_ENABLED = False
ACCOUNT_SIGNUP_FIELDS = ["email*", "password1*", "password2*"]
HEADLESS_ONLY = False
LOGIN_REDIRECT_URL = "/"
ACCOUNT_SIGNUP_REDIRECT_URL = "/"
ACCOUNT_EMAIL_CONFIRMATION_ANONYMOUS_REDIRECT_URL = "/"
ACCOUNT_AUTHENTICATED_LOGIN_REDIRECTS = True

# -------------------------------------------------- REST_AUTH --------------------------------------------------

REST_AUTH = {
    'REGISTER_SERIALIZER': 'base_user.serializers.CustomRegisterSerializer',
    'LOGIN_SERIALIZER': 'base_user.serializers.CustomLoginSerializer',
    'USER_DETAILS_SERIALIZER': 'base_user.serializers.CustomUserDetailsSerializer',
    'PASSWORD_RESET_USE_SITES_DOMAIN': True,
    'USE_JWT': True,
    # 'JWT_AUTH_COOKIE': '',
    # 'JWT_AUTH_REFRESH_COOKIE': '',
}

REST_FRAMEWORK = {
    'DEFAULT_AUTHENTICATION_CLASSES': (
        'dj_rest_auth.jwt_auth.JWTCookieAuthentication',
    ),
    "DEFAULT_SCHEMA_CLASS": "drf_spectacular.openapi.AutoSchema"
}

# JWT Configuration

SIMPLE_JWT = {
    'ACCESS_TOKEN_LIFETIME': timedelta(days=1000),
    'REFRESH_TOKEN_LIFETIME': timedelta(days=1000),
}

# Email Configuration (for development)
EMAIL_BACKEND = 'django.core.mail.backends.console.EmailBackend'
# SMTP for email

# EMAIL_BACKEND = 'django.core.mail.backends.smtp.EmailBackend'
# EMAIL_HOST = 'smtp.gmail.com'
# EMAIL_PORT = 587
# EMAIL_HOST_USER = 'testinguser1110@gmail.com'
# EMAIL_HOST_PASSWORD = 'unffuqgygrhbchxq'
# EMAIL_USE_TLS = True
# FROM_EMAIL = 'testinguser1110@gmail.com'


# CORS Configuration (if needed for frontend)
CORS_ALLOWED_ORIGINS = [
    "http://localhost:3000",
    "http://127.0.0.1:3000",
    "http://localhost:8080",
    "http://127.0.0.1:8080",
]

CORS_ALLOW_CREDENTIALS = True

# Firebase MCP Configuration
INSTALLED_APPS += ["firebase_admin_mcp"]
SERVICE_ACCOUNT_KEY_PATH = os.getenv(
    "SERVICE_ACCOUNT_KEY_PATH", "serviceAccountKey.json")
FIREBASE_STORAGE_BUCKET = os.getenv("FIREBASE_STORAGE_BUCKET", "")
ENABLE_FIRESTORE = True
ENABLE_AUTH = True
ENABLE_STORAGE = True
MCP_TRANSPORT = os.getenv("MCP_TRANSPORT", "stdio")       # "stdio" or "http"
MCP_HTTP_PORT = int(os.getenv("MCP_HTTP_PORT", "8000"))



from django.contrib.auth.base_user import BaseUserManager
from django.utils.translation import gettext_lazy as _


class CustomUserManager(BaseUserManager):
    """
    Custom user model manager where email is the unique identifiers
    for authentication instead of usernames.
    """

    def create_user(self, email, password, **extra_fields):
        """
        Create and save a User with the given email and password.
        """
        if not email:
            raise ValueError(_("The Email must be set"))
        email = self.normalize_email(email)
        user = self.model(email=email, **extra_fields)
        user.set_password(password)
        user.save()
        return user

    def create_superuser(self, email, password, **extra_fields):
        """
        Create and save a SuperUser with the given email and password.
        """
        extra_fields.setdefault("is_staff", True)
        extra_fields.setdefault("is_superuser", True)
        extra_fields.setdefault("is_active", True)

        if extra_fields.get("is_staff") is not True:
            raise ValueError(_("Superuser must have is_staff=True."))
        if extra_fields.get("is_superuser") is not True:
            raise ValueError(_("Superuser must have is_superuser=True."))
        return self.create_user(email, password, **extra_fields)


from firebase_admin import auth
from django.conf import settings

from django.contrib.auth import get_user_model
from django.contrib.auth.models import Group
from django.core.exceptions import ValidationError as DjangoValidationError
from django.utils.translation import gettext_lazy as _

from rest_framework.exceptions import ValidationError
from rest_framework.serializers import (
    CharField,
    as_serializer_error,
    BooleanField,
    SlugRelatedField
)

from allauth.account.utils import setup_user_email
from allauth.account.adapter import get_adapter

from rest_framework.serializers import ModelSerializer
from dj_rest_auth.serializers import LoginSerializer, UserDetailsSerializer
from dj_rest_auth.registration.serializers import RegisterSerializer

User = get_user_model()


class CustomLoginSerializer(LoginSerializer):
    username = None

    @staticmethod
    def validate_auth_user_group(user):
        pass
        # if not user.groups.filter(name='admin').exists():
        #     raise ValidationError(_('User is not an Admin user.'))

    def validate(self, attrs):
        username = attrs.get('username')
        email = attrs.get('email')
        password = attrs.get('password')
        user = self.get_auth_user(username, email, password)

        if not user:
            msg = _('Unable to log in with provided credentials.')
            raise ValidationError(msg)

        # Did we get back an active user?
        self.validate_auth_user_status(user)
        # Is the user in the correct group?
        # (e.g. admin, teacher, student)
        self.validate_auth_user_group(user)

        # If required, is the email verified?
        if 'dj_rest_auth.registration' in settings.INSTALLED_APPS:
            self.validate_email_verification_status(user, email=email)

        attrs['user'] = user
        return attrs


class CustomRegisterSerializer(RegisterSerializer):
    username = None
    is_terms_agreed = BooleanField(default=False)

    def get_cleaned_data(self):
        cleaned_data = super().get_cleaned_data()
        cleaned_data['is_terms_agreed'] = self.validated_data.get(
            'is_terms_agreed', False)
        return cleaned_data

    def validate_email(self, email):
        if User.objects.filter(email=email).exists():
            raise ValidationError(
                _("A user with this email address already exists."))
        return email

    def save(self, request):
        adapter = get_adapter()
        self.cleaned_data = self.get_cleaned_data()
        user = adapter.new_user(request)
        user = adapter.save_user(request, user, self, commit=False)
        user.is_terms_agreed = self.cleaned_data['is_terms_agreed']

        password = self.cleaned_data.get('password1')
        if password:
            try:
                adapter.clean_password(password, user=user)
            except DjangoValidationError as exc:
                raise ValidationError(as_serializer_error(exc))

        # result = auth.create_user(email=user.email, password=password)
        # user.firebase_uid = result.uid
        user.firebase_uid = user.id.hex

        user.is_staff = True
        user.save()
        self.custom_signup(request, user)
        setup_user_email(request, user, [])
        return user


class CustomUserDetailsSerializer(UserDetailsSerializer):
    """
    Nested serializer for User model to return only required fields.
    """
    groups = SlugRelatedField(many=True, read_only=True, slug_field="name")

    class Meta:
        model = User
        fields = UserDetailsSerializer.Meta.fields + \
            ('groups', 'phone', 'firebase_uid', 'is_terms_agreed')


class UserSerializer(ModelSerializer):
    """
    Nested serializer for User model to return only required fields.
    """
    class Meta:
        model = User
        fields = ['id', 'email', 'first_name', 'last_name', 'phone']



"""
Firebase Admin SDK initialization for MCP server.
"""
import os
import firebase_admin
from firebase_admin import credentials, firestore, auth, storage
from django.conf import settings

# Global variables to hold initialized services
_db = None
_auth_client = None
_bucket = None
_initialized = False


def _initialize_firebase():
    """Initialize Firebase Admin SDK once."""
    global _db, _auth_client, _bucket, _initialized

    if _initialized:
        return

    # Initialize Firebase Admin SDK once
    if not firebase_admin._apps:
        try:
            cred = credentials.Certificate(settings.SERVICE_ACCOUNT_KEY_PATH)
            firebase_admin.initialize_app(cred)
        except Exception as e:
            print(f"Failed to initialize Firebase Admin SDK: {e}")
            raise

    # Initialize Firestore
    if settings.ENABLE_FIRESTORE:
        _db = firestore.client()

    # Initialize Auth
    if settings.ENABLE_AUTH:
        _auth_client = auth

    # Initialize Storage
    if settings.ENABLE_STORAGE and settings.FIREBASE_STORAGE_BUCKET:
        try:
            _bucket = storage.bucket(settings.FIREBASE_STORAGE_BUCKET)
        except Exception as e:
            print(f"Failed to initialize Storage bucket: {e}")
            _bucket = None

    _initialized = True


def get_db():
    """Get Firestore database client."""
    if not _initialized:
        _initialize_firebase()
    return _db


def get_auth():
    """Get Firebase Auth client."""
    if not _initialized:
        _initialize_firebase()
    return _auth_client


def get_bucket():
    """Get Firebase Storage bucket."""
    if not _initialized:
        _initialize_firebase()
    return _bucket



import uuid
from django.db import models
from django.contrib.contenttypes.fields import GenericForeignKey
from django.contrib.contenttypes.models import ContentType
from django.contrib.auth.models import AbstractUser
from phonenumber_field.modelfields import PhoneNumberField
from .validators import validate_i18nJSON


def get_choicesets_enum(className):
    class_vars = vars(className)
    choicesets = []
    for i in class_vars:
        if type(class_vars[i]) == models.enums.ChoicesMeta:
            choicesets.append(
                {i: [x for x in class_vars[i]._member_names_ if x[0] != "_"]}
            )
    return choicesets


class i18nJSONField(models.JSONField):
    default_validators = [validate_i18nJSON]


class BaseModel(models.Model):
    """BaseModel

    Defines the following fields

        id:UUID
        created_on:DateTime
        edited_on:DateTime
        _data:JSON(null&blank allowed)

    And the following class methods

        get_choicesets()->dict
            returns all choicefields and their choices
        get_fields()->list
            returns all fields defined in the model
        get_related_fields()->list
            returns all _set fields aka forward references
        get_all_fields()->list
            returns all fields including forward references

    """

    id = models.UUIDField(primary_key=True, default=uuid.uuid4, editable=False)
    created_on = models.DateTimeField(auto_now_add=True)
    edited_on = models.DateTimeField(auto_now=True)
    _data = models.JSONField(null=True, blank=True)

    class Meta:
        abstract = True

    @classmethod
    def get_choicesets(cls) -> dict:
        choicesets = dict()
        for i in cls._meta.fields:
            if i.choices != None:
                choicesets[i.name] = list(dict(i.choices))
            else:
                continue
        return choicesets

    @classmethod
    def get_fields(cls) -> list:
        return [x.name for x in cls._meta.fields]

    @classmethod
    def get_related_fields(cls) -> list:
        return [x.name for x in cls._meta.related_objects] + [
            x.name for x in cls._meta.many_to_many
        ]

    @classmethod
    def get_many_to_many_fields(cls) -> list:
        return [x.name for x in cls._meta.many_to_many]

    @classmethod
    def get_all_fields(cls) -> list:
        return (
            [x.name for x in cls._meta.fields]
            + [x.name for x in cls._meta.related_objects]
            + [x.name for x in cls._meta.many_to_many]
        )

    @classmethod
    def get_all_fields_verbose(cls) -> list:
        return (
            [x.verbose_name for x in cls._meta.fields]
            + [x.verbose_name for x in cls._meta.related_objects]
            + [x.verbose_name for x in cls._meta.many_to_many]
        )

    @classmethod
    def generate_i18nJSON(cls, lang_codes):
        i18nFields = ["id"] + [
            x.name for x in cls._meta.fields if type(x) == i18nJSONField
        ]
        i18nTexts = cls.objects.values_list(*i18nFields)
        i18nTextGroups = dict()
        for texts in i18nTexts:
            for i in range(len(i18nFields)):
                if i18nFields[i] not in i18nTextGroups:
                    i18nTextGroups[i18nFields[i]] = []
                i18nTextGroups[i18nFields[i]].append(texts[i])
        i18nJSON = dict()
        for lang in lang_codes:
            i18nJSON[lang] = dict()
            i18nJSON[lang][cls.__name__] = dict()
            for i in range(len(i18nTextGroups["id"])):
                i18nJSON[lang][cls.__name__][str(
                    i18nTextGroups["id"][i])] = dict()
                for field in i18nFields[1:]:
                    if i18nTextGroups[field][i]:
                        i18nJSON[lang][cls.__name__][str(i18nTextGroups["id"][i])][
                            field
                        ] = i18nTextGroups[field][i][lang]
                    else:
                        i18nJSON[lang][cls.__name__][str(i18nTextGroups["id"][i])][
                            field
                        ] = None
        return i18nJSON

    @classmethod
    def get_all_search_fields(cls) -> list:
        search_fields = list()
        for field in cls._meta.fields:
            if field.is_relation:
                for field_relation in cls._meta.get_field(field.name).remote_field.model._meta.fields:
                    if not field_relation.is_relation and field_relation.name not in ['id', 'created_on', 'edited_on', '_data']:
                        search_fields.append(
                            f'{field.name}__{field_relation.name}')
            else:
                search_fields.append(field.name)
        return search_fields


class AbstractBaseUser(BaseModel, AbstractUser):
    phone = PhoneNumberField(null=True, blank=True, unique=True)
    full_name = models.CharField(max_length=1024, null=True, blank=True)
    avatar = models.ImageField(upload_to="avatars/", null=True, blank=True)

    class Meta:
        abstract = True



from django.db import models
from django.utils.translation import gettext_lazy as _
from base.models import AbstractBaseUser
from base_user.managers import CustomUserManager


class User(AbstractBaseUser):

    username = None

    USERNAME_FIELD = "email"
    REQUIRED_FIELDS = []

    objects = CustomUserManager()
    email = models.EmailField(
        _("Email Address"), unique=True, null=True, blank=True)
    avatar = models.ImageField(
        upload_to="avatars/", default="avatars/default_profile_avatar.jpg")
    is_terms_agreed = models.BooleanField(default=False)
    created_by = models.ForeignKey(
        'self', null=True, blank=True, on_delete=models.SET_NULL)
    firebase_uid = models.CharField(max_length=128, null=True, blank=True)

    def __str__(self):
        return self.email if self.email else str(self.id)



from django.dispatch import receiver, Signal
from django.db.models.signals import post_save, post_delete, m2m_changed
from .models import Activity


@receiver(post_save)
def my_callback(sender, instance, created, raw, using, update_fields, **kwargs):
    if created:
        Activity.objects.create(
            content_object=instance, operation=Activity.OperationChoiceSet.CREATED
        )
    else:
        Activity.objects.create(
            content_object=instance, operation=Activity.OperationChoiceSet.UPDATED
        )



import json
from django.core.exceptions import ValidationError

i18nLangCodes = {
    "Cy-az-AZ",
    "Cy-sr-SP",
    "Cy-uz-UZ",
    "Lt-az-AZ",
    "Lt-sr-SP",
    "Lt-uz-UZ",
    "aa",
    "ab",
    "ae",
    "af",
    "af-ZA",
    "ak",
    "am",
    "an",
    "ar",
    "ar-AE",
    "ar-BH",
    "ar-DZ",
    "ar-EG",
    "ar-IQ",
    "ar-JO",
    "ar-KW",
    "ar-LB",
    "ar-LY",
    "ar-MA",
    "ar-OM",
    "ar-QA",
    "ar-SA",
    "ar-SY",
    "ar-TN",
    "ar-YE",
    "as",
    "av",
    "ay",
    "az",
    "ba",
    "be",
    "be-BY",
    "bg",
    "bg-BG",
    "bh",
    "bi",
    "bm",
    "bn",
    "bo",
    "br",
    "bs",
    "ca",
    "ca-ES",
    "ce",
    "ch",
    "co",
    "cr",
    "cs",
    "cs-CZ",
    "cu",
    "cv",
    "cy",
    "da",
    "da-DK",
    "de",
    "de-AT",
    "de-CH",
    "de-DE",
    "de-LI",
    "de-LU",
    "div-MV",
    "dv",
    "dz",
    "ee",
    "el",
    "el-GR",
    "en",
    "en-AU",
    "en-BZ",
    "en-CA",
    "en-CB",
    "en-GB",
    "en-IE",
    "en-JM",
    "en-NZ",
    "en-PH",
    "en-TT",
    "en-US",
    "en-ZA",
    "en-ZW",
    "eo",
    "es",
    "es-AR",
    "es-BO",
    "es-CL",
    "es-CO",
    "es-CR",
    "es-DO",
    "es-EC",
    "es-ES",
    "es-GT",
    "es-HN",
    "es-MX",
    "es-NI",
    "es-PA",
    "es-PE",
    "es-PR",
    "es-PY",
    "es-SV",
    "es-UY",
    "es-VE",
    "et",
    "et-EE",
    "eu",
    "eu-ES",
    "fa",
    "fa-IR",
    "ff",
    "fi",
    "fi-FI",
    "fj",
    "fo",
    "fo-FO",
    "fr",
    "fr-BE",
    "fr-CA",
    "fr-CH",
    "fr-FR",
    "fr-LU",
    "fr-MC",
    "fy",
    "ga",
    "gd",
    "gl",
    "gl-ES",
    "gn",
    "gu",
    "gu-IN",
    "gv",
    "ha",
    "he",
    "he-IL",
    "hi",
    "hi-IN",
    "ho",
    "hr",
    "hr-HR",
    "ht",
    "hu",
    "hu-HU",
    "hy",
    "hy-AM",
    "hz",
    "ia",
    "id",
    "id-ID",
    "ie",
    "ig",
    "ii",
    "ik",
    "io",
    "is",
    "is-IS",
    "it",
    "it-CH",
    "it-IT",
    "iu",
    "ja",
    "ja-JP",
    "jv",
    "ka",
    "ka-GE",
    "kg",
    "ki",
    "kj",
    "kk",
    "kk-KZ",
    "kl",
    "km",
    "kn",
    "kn-IN",
    "ko",
    "ko-KR",
    "kr",
    "ks",
    "ku",
    "kv",
    "kw",
    "ky",
    "ky-KZ",
    "la",
    "lb",
    "lg",
    "li",
    "ln",
    "lo",
    "lt",
    "lt-LT",
    "lu",
    "lv",
    "lv-LV",
    "mg",
    "mh",
    "mi",
    "mk",
    "mk-MK",
    "ml",
    "mn",
    "mn-MN",
    "mr",
    "mr-IN",
    "ms",
    "ms-BN",
    "ms-MY",
    "mt",
    "my",
    "na",
    "nb",
    "nb-NO",
    "nd",
    "ne",
    "ng",
    "nl",
    "nl-BE",
    "nl-NL",
    "nn",
    "nn-NO",
    "no",
    "nr",
    "nv",
    "ny",
    "oc",
    "oj",
    "om",
    "or",
    "os",
    "pa",
    "pa-IN",
    "pi",
    "pl",
    "pl-PL",
    "ps",
    "pt",
    "pt-BR",
    "pt-PT",
    "qu",
    "rm",
    "rn",
    "ro",
    "ro-RO",
    "ru",
    "ru-RU",
    "rw",
    "sa",
    "sa-IN",
    "sc",
    "sd",
    "se",
    "sg",
    "si",
    "sk",
    "sk-SK",
    "sl",
    "sl-SI",
    "sm",
    "sn",
    "so",
    "sq",
    "sq-AL",
    "sr",
    "ss",
    "st",
    "su",
    "sv",
    "sv-FI",
    "sv-SE",
    "sw",
    "sw-KE",
    "ta",
    "ta-IN",
    "te",
    "te-IN",
    "tg",
    "th",
    "th-TH",
    "ti",
    "tk",
    "tl",
    "tn",
    "to",
    "tr",
    "tr-TR",
    "ts",
    "tt",
    "tt-RU",
    "tw",
    "ty",
    "ug",
    "uk",
    "uk-UA",
    "ur",
    "ur-PK",
    "uz",
    "ve",
    "vi",
    "vi-VN",
    "vo",
    "wa",
    "wo",
    "xh",
    "yi",
    "yo",
    "za",
    "zh",
    "zh-CHS",
    "zh-CHT",
    "zh-CN",
    "zh-HK",
    "zh-MO",
    "zh-SG",
    "zh-TW",
    "zu",
}


def validate_i18nJSON(value):
    try:
        json.loads(str(value).replace("'", '"'))
    except:
        raise ValidationError(
            'JSON is invalid! Use format \{"en"\:"Text as per language code in key"} You sent: '
            + str(value)
        )
    for v in value:
        if type(value[v]) != str or v not in i18nLangCodes:
            raise ValidationError(f'JSON is invalid! Country code does not exist Source: {v} :{str(value[v])}')



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="django-firebase-mcp",                      # This is the name of the package
    version="0.0.1",                                 # The initial release version
    author="Raghvendra Dasila",                      # Full name of the author
    description="A comprehensive Django app that implements Firebase Model Context Protocol (MCP) server, enabling AI agents to interact with Firebase services seamlessly through structured tools and interfaces.",
    long_description=long_description,               # Long description read from the readme file
    long_description_content_type="text/markdown",
    packages=setuptools.find_packages(where='django-firebase-mcp'),  # List of all python modules to be installed
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],                                              # Information to filter the project on PyPi website
    python_requires='>=3.10',                       # Minimum version requirement of the package
    py_modules=["django-firebase-mcp"],              # Name of the python package
    package_dir={'': 'django-firebase-mcp'},         # Directory of the source code of the package
    install_requires=[]                              # Install other dependencies if any
)